@@ -1,6 +1,9 @@
-from typing import Type
+from typing import List, Type
 
-from eyja.interfaces.db import BaseStorageModel
+from eyja.interfaces.db import (
+    BaseStorageModel,
+    DataFilter,
+)
 from eyja.errors import ObjectNotFoundError
 
 
@@ -20,3 +23,12 @@ async def get_for_user(
         )
 
     return items[0]
+
+async def find_for_user(
+    model_cls: Type[BaseStorageModel],
+    filter: DataFilter,
+    user: BaseStorageModel
+) -> List[BaseStorageModel]:
+    filter.fields['user_id'] = user.object_id
+
+    return await model_cls.find(filter)
